@@ -10,7 +10,7 @@ options(
     setup=Bunch(
         name="stockpyle",
         packages=["stockpyle", "stockpyle.ext"],
-        version="0.0.6",
+        version="0.0.7",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+stockpyle@gmail.com",
@@ -41,11 +41,6 @@ in stockpyle.stores:
 * MemcacheStore - http://pypi.python.org/pypi/python-memcached
 * ShoveStore - http://pypi.python.org/pypi/shove
 * SqlAlchemyStore - http://pypi.python.org/pypi/SQLAlchemy
-
-The stockpyle library also provides base classes to define your own Stores:
-
-* BaseStore (for implementing your own store)
-* BaseDictionaryStore (for implementing your own store that has a dictionary-style interface)
     
 Stores can perform 6 operations on objects:
 
@@ -63,6 +58,9 @@ that object.  Read the quickstart below for more details.
 Quickstart
 ==========
 
+Basics
+------
+
 The fastest way to get up and running is to create an in-memory Store::
     
     from stockpyle.stores import ProcessMemoryStore
@@ -124,7 +122,7 @@ And that's basics of using stockpyle.  No matter what Store object
 you use, you can use this API to store, retrieve, and delete objects.
 
 Chained Storage (e.g. write-through caching)
-============================================
+--------------------------------------------
 
 Persistent storage is often expensive to access, making caching a necessity.
 However, maintaining cache consistency is difficult and error-prone.  The stockpyle
@@ -147,6 +145,13 @@ the persistent object.
 During puts, gets, and deletes, stockpyle will keep the upper layers (the caches)
 populated with the latest data from lower layers (the persistent database).
 
+Bugs
+====
+
+This is still an early-stage project.  Please file bugs on Google Code:
+
+http://code.google.com/p/stockpyle/
+
 Advanced
 ========
 
@@ -258,15 +263,26 @@ And retrieve it as either a Car or an automobile::
 Note that there is a tradeoff in storage duplication when doing this.  Every Car
 object is indexed as a Car and as an Automobile (2 locations in storage).
 
+Memcache Integration
+--------------------
+
+In order to enable MemcacheStore, you will need to install the python-memcached module:
+
+http://pypi.python.org/pypi/python-memcached
+
+The MemcacheStore supports polymorphic queries.  The native memcache API is used to support
+object expiration and batched operations.
+
 SQLAlchemy Integration
 ----------------------
 
-If you have SQLAlchemy-backed objects, stockpyle can store these objects like
-any other Python object.  Just make sure that your object is mapped to SQLAlchemy
-metadata, either with explicit mapping or via the declarative plugin.
+In order to enable SqlAlchemyStore, you will need to install the SQLAlchemy module:
+
+http://pypi.python.org/pypi/SQLAlchemy
 
 Typically, in SQLAlchemy you will use a session to store and retrieve your mapped objects::
 
+    # create the object
     obj = MyMappedObject()
     
     # store it
@@ -278,8 +294,12 @@ Typically, in SQLAlchemy you will use a session to store and retrieve your mappe
 
 You can do the same thing through a SqlAlchemyStore::
     
+    # create the store
     store = SqlAlchemyStore("sqlite:///:memory:")
     
+    # create the object
+    obj = MyMappedObject()
+    
     # store it
     store.put(obj)
     
@@ -303,7 +323,7 @@ Now you can put this SqlAlchemyStore in a ChainedStore for write-through caching
 What if you want to continue accessing SQLAlchemy directly?  This is a common
 case, since obviously stockpyle does not provide the rich querying API that
 SQLAlchemy has.  To ensure that your stockpyle cache does not get out of sync
-with queries done with your own SQLAlchemy sessions, simply add the
+with queries done in your own SQLAlchemy sessions, simply add the
 StockpyleSessionExtension to your session object::
     
     from sqlalchemy.orm import sessionmaker
@@ -316,6 +336,38 @@ StockpyleSessionExtension to your session object::
 
 Now, whenever *my_session* performs an insert, update, or delete on an object,
 it will also perform the corresponding puts and deletes in *mc_store*.
+
+Shove Integration
+-----------------
+
+In order to enable ShoveStore, you will need to install the shove module:
+
+http://pypi.python.org/pypi/shove
+
+The stockpyle API works well with any dictionary-style storage.  The Shove library provides
+a very broad array of storage backends with a dictionary-style interface.  You can create
+a ShoveStore easily in stockpyle::
+    
+    from stockpyle.stores import ShoveStore
+    
+    s3_store = ShoveStore(shoveuri="s3://s3key:s3secret@whatever_bucket_name_you_want")
+
+ShoveStores support polymorphic storage and object expiration.  Every object stored in the Shove is stored at
+human-readable key as a tuple (obj, expiredate).
+
+Defining a custom Store
+-----------------------
+Although stockpile contains most of the stores you will need to support
+any storage backend (especially through the Shove integration), you may
+want to implement your own Store.  The stockpyle library provides two base classes to define your own Stores:
+
+* BaseStore (for implementing your own store from scratch)
+* BaseDictionaryStore (for implementing your own store that has a dictionary-style interface)
+
+To make your own store, simply create a subclass of either of these stores and implement
+the 6 storage methods (put, get, delete, batch_put, batch_get, batch_delete).
+
+Please browse the source code for detailed examples of how to implement your own store.
 ''',
         zip_safe = False,
         )
