@@ -1,4 +1,6 @@
-from stockpyle._memcache import MemcacheStore
-from stockpyle._sqlalchemy import SqlAlchemyStore
+from stockpyle._base import BaseStore
 from stockpyle._procmem import ProcessMemoryStore
+from stockpyle._memcache import MemcacheStore
+from stockpyle._shove import ShoveStore
+from stockpyle._sqlalchemy import SqlAlchemyStore
 from stockpyle._chained import ChainedStore
